@@ -337,8 +337,9 @@ class MedmMainWidget(MedmBaseWidget):
             msg = "Could not find file: " + fname
             raise ValueError(msg)
         self.given_filename = fname
-        with open(fname, "r") as fp:
-            return fp.readlines()
+        # brutal: simply discard any non-utf8 characters
+        buf = open(fname, "r", encoding='utf8', errors='ignore').readlines()
+        return buf
 
     def parseAdlBuffer(self, buf):  # lgtm [py/similar-function]
         logger.debug("\n" * 2)
@@ -580,7 +581,8 @@ class MedmRelatedDisplayWidget(MedmGenericWidget):
         for block in blocks:
             if not block.symbol.startswith("display["):
                 continue
-            del self.contents[block.symbol]
+            if block.symbol in self.contents:
+                del self.contents[block.symbol]
             aa = self.locateAssignments(buf[block.start + 1 : block.end])
             row = block.symbol.replace("[", " ").replace("]", "").split()[-1]
             displays[row] = aa
